Text:
1. On install cmd
    Check first if Claude is installed
    Hint what environment is for
    Default web timeout to 30s
2. On uvx starbridge
    Rethink if to make all env variables optional, so one can just run
